import requests
from ._base_url import BASE_URL

SUDO_URL = f"{BASE_URL}/sudos/"


def get_sudos(chat_id: int):
    try:
        r = requests.get(f"{SUDO_URL}{chat_id}")
        z: list[int] = r.json()["sudos"]
        return z
    except KeyError:
        return None


def add_sudo(chat_id: int, user_id: int):
    r = requests.post(f"{SUDO_URL}", json={
        "chat_id": chat_id,
        "user_id": user_id
    })
    return r.status_code


def del_sudo(chat_id: int, user_id: int):
    r = requests.delete(f"{SUDO_URL}", json={
        "chat_id": chat_id,
        "user_id": user_id
    })
    return r.status_code


def put_sudo(chat_id: int, user_id: int) -> dict:
    r = requests.put(f"{SUDO_URL}{chat_id}", json={
        "chat_id": chat_id,
        "user_id": user_id
    })
    return r.json()



import requests
from . import emoji, add_chat
from ._base_url import BASE_URL


def get_message(chat_id: int, key: str) -> str:
    r = requests.get(f"{BASE_URL}/message", params={
        "chat_id": chat_id,
        "key": key
    })
    try:
        message = r.json()["message"]
    except KeyError:
        add_chat(chat_id, "en")
        message = r.json()["message"]
    return message


def get_available_language(lang: str = None):
    if not lang:
        r = requests.get(f"{BASE_URL}/langs")
        language = r.json()["language"]
        return list(language)
    r = requests.get(f"{BASE_URL}/langs", params={
        "lang": lang
    })
    key = r.json()["key"]
    return dict(key)


def paste(content: str):
    """
    :param content: str
    :return: {"link": link, "preview": link_preview}
    """
    r = requests.post(f"{BASE_URL}/paste", json={"content": content})
    return r.json()


def get_stats():
    res = requests.get(f"{BASE_URL}/gstats").json()
    chats = res["chats"]
    pms = res["pm"]
    return chats, pms


kode = get_available_language()
lang_flags = {
    "en": f"{emoji.FLAG_UNITED_STATES} English",
    "id": f"{emoji.FLAG_INDONESIA} Indonesia",
    "su": f"{emoji.FLAG_INDONESIA} Sundanese",
    "jv": f"{emoji.FLAG_INDONESIA} Javanese",
    "jp": f"{emoji.FLAG_JAPAN} Japan",
    "hi": f"{emoji.FLAG_INDIA} India",
    "gj": f"{emoji.FLAG_INDIA} Gujarat",
    "si": f"{emoji.FLAG_SRI_LANKA} Sinhala",
    "ta": f"{emoji.FLAG_SRI_LANKA} Tamil"
}



from json import JSONDecodeError

import requests

from ._base_url import BASE_URL
from .other import get_available_language


def add_chat(chat_id: int, lang="en"):
    """
    :param chat_id:
    :param lang: str
    :return: 201 or 404 or 500
    """
    r = requests.post(f"{BASE_URL}/chats/", json={
        "chat_id": chat_id,
        "lang": lang
    })
    return r.status_code


def get_chat(chat_id: int) -> dict:
    """
    For get information of chat
    :param chat_id: int
    :return: { "chat_id": chat_id, "lang": lang } or {}}
    """
    try:
        r = requests.get(f"{BASE_URL}/chats/{chat_id}")
        return r.json()
    except JSONDecodeError:
        return {}


def set_lang(chat_id: int, lang: str) -> int:
    """
    :param chat_id: int
    :param lang: str
    :return: 200 | 404
    """
    if lang not in get_available_language():
        return 404
    r = requests.put(f"{BASE_URL}/chats/{chat_id}?lang={lang}")
    return r.status_code


def del_chat(chat_id: int):
    """
    :param chat_id: int
    :return: 200 | 404 | 500
    """
    r = requests.delete(f"{BASE_URL}/chats/{chat_id}")
    return r.status_code



from setuptools import setup

setup(
    name='solidAPI',
    version='0.1.8.6',
    packages=['solidAPI'],
    url='https://github.com/DoellBarr',
    license='MIT',
    author='Shohih Abdul',
    author_email='shohih242@gmail.com',
    description='A Library for solidAPI',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
